TucoTuco.Actions
SourceSummary
| attach_file(text, filename) | Attach a file to a file field. Finds the field by name, id or label |
| check(text) | Check a checkbox. Finds the checkbox by id, name or label |
| choose(text) | Choose a radio button. Finds the button by id or label |
| click_button(text) | Click on a button found by id, value or label. Also clicks on form submit inputs |
| click_link(text) | Click a link found by id, text or label |
| fill_in(field, text) | Fill in a field with the specified text. Finds the field by id, name or label |
| select(text) | Select an option from a select. Finds the option by it’s text or id |
| select(text, list2) | Select an option from a specified select. Finds the option from it’s text or id and finds the select from it’s id, name or label |
| uncheck(text) | Uncheck a checkbox. Finds the checkbox by id, name or label |
| unselect(text) | Currently not working. Do not use |
Functions
Attach a file to a file field. Finds the field by name, id or label.
Filename must specify the path to a file that exists.
Click on a button found by id, value or label. Also clicks on form submit inputs.
Fill in a field with the specified text. Finds the field by id, name or label.
See WebDriver.Keys if you need to use non text characters.
Select an option from a select. Finds the option by it’s text or id.
Select an option from a specified select. Finds the option from it’s text or id and finds the select from it’s id, name or label.