tuco_tuco v0.7.1
Modules summary ↑
| TucoTuco | TucoTuco is a web testing suite for Elixir applications. To use it make sure the TucoTuco application is running by specifying it in your mix.exs file or doing: |
| TucoTuco.Actions | |
| TucoTuco.Assertions | |
| TucoTuco.Config | |
| TucoTuco.DSL | |
| TucoTuco.Finder | |
| TucoTuco.Page | This module contains all the functions associated with querying the state of the current page |
| TucoTuco.Retry | |
| TucoTuco.SessionPool | The session pool is responsible for maintaining state which references the underlying WebDriver sessions that are running |
| TucoTuco.SessionPool.SessionPoolState | |
| TucoTuco.Supervisor |